@@ -635,7 +635,8 @@ impl DkgCommand {
                 message,
             } => {
                 let variant = Variant::DkgMessage { dkg_key, message };
-                let message = Message::single_src(node, DstLocation::Direct, variant, None)?;
+                let message =
+                    Message::single_src(node, DstLocation::DirectAndUnrouted, variant, None)?;
 
                 Ok(Command::send_message_to_nodes(
                     recipients.clone(),
@@ -668,7 +669,8 @@ impl DkgCommand {
                     proof,
                     non_participants,
                 };
-                let message = Message::single_src(node, DstLocation::Direct, variant, None)?;
+                let message =
+                    Message::single_src(node, DstLocation::DirectAndUnrouted, variant, None)?;
 
                 Ok(Command::send_message_to_nodes(
                     recipients.clone(),
