@@ -61,7 +61,7 @@ impl MessageFilter {
 
     pub fn insert_incoming(&mut self, msg: &Message) {
         // Not filtering direct messages.
-        if let DstLocation::Direct = msg.dst() {
+        if let DstLocation::DirectAndUnrouted = msg.dst() {
             return;
         }
         let _ = self.incoming.insert(*msg.hash(), ());
@@ -72,7 +72,7 @@ impl MessageFilter {
     //
     pub fn filter_outgoing(&mut self, msg: &Message, pub_id: &XorName) -> FilteringResult {
         // Not filtering direct messages.
-        if let DstLocation::Direct = msg.dst() {
+        if let DstLocation::DirectAndUnrouted = msg.dst() {
             return FilteringResult::NewMessage;
         }
 
