@@ -15,7 +15,7 @@ use crate::{
     node::Node,
     relocation::{RelocatePayload, SignedRelocateDetails},
     routing::comm::SendStatus,
-    section::{Section, SectionAuthorityProvider, SectionChain},
+    section::{Section, SectionAuthorityProvider},
     FIRST_SECTION_MAX_AGE, FIRST_SECTION_MIN_AGE,
 };
 use bytes::Bytes;
@@ -23,6 +23,7 @@ use futures::future;
 use itertools::Itertools;
 use rand::seq::IteratorRandom;
 use resource_proof::ResourceProof;
+use secured_linked_list::SecuredLinkedList;
 use sn_data_types::PublicKey;
 use sn_messaging::{
     node::RoutingMsg,
@@ -447,7 +448,8 @@ impl<'a> State<'a> {
         info!("Sending {:?} to {:?}", join_request, recipients);
 
         let variant = Variant::JoinRequest(Box::new(join_request));
-        let message = Message::single_src(&self.node, DstLocation::Direct, variant, None)?;
+        let message =
+            Message::single_src(&self.node, DstLocation::DirectAndUnrouted, variant, None)?;
         let node_msg = RoutingMsg::new(message.to_bytes());
 
         let _ = self
@@ -611,7 +613,7 @@ enum JoinResponse {
     Approval {
         section_auth: Proven<SectionAuthorityProvider>,
         genesis_key: bls::PublicKey,
-        section_chain: SectionChain,
+        section_chain: SecuredLinkedList,
     },
     Retry {
         section_auth: SectionAuthorityProvider,
@@ -789,10 +791,10 @@ mod tests {
             // Send NodeApproval
             let section_auth = proven(sk, section_auth.clone())?;
             let member_info = proven(sk, MemberInfo::joined(peer))?;
-            let proof_chain = SectionChain::new(pk);
+            let proof_chain = SecuredLinkedList::new(pk);
             let message = Message::single_src(
                 &bootstrap_node,
-                DstLocation::Direct,
+                DstLocation::DirectAndUnrouted,
                 Variant::NodeApproval {
                     genesis_key: pk,
                     section_auth,
@@ -1241,7 +1243,7 @@ mod tests {
             // Send `Rejoin` with bad prefix
             let message = Message::single_src(
                 &bootstrap_node,
-                DstLocation::Direct,
+                DstLocation::DirectAndUnrouted,
                 Variant::JoinRetry {
                     section_auth: gen_section_authority_provider(bad_prefix, ELDER_SIZE).0,
                     section_key: bls::SecretKey::random().public_key(),
@@ -1264,7 +1266,7 @@ mod tests {
             // Send `Rejoin` with good prefix
             let message = Message::single_src(
                 &bootstrap_node,
-                DstLocation::Direct,
+                DstLocation::DirectAndUnrouted,
                 Variant::JoinRetry {
                     section_auth: gen_section_authority_provider(good_prefix, ELDER_SIZE).0,
                     section_key: bls::SecretKey::random().public_key(),
