@@ -33,17 +33,24 @@ use crate::{
     messages::Message,
     node::Node,
     peer::Peer,
-    section::{SectionAuthorityProvider, SectionChain},
+    section::SectionAuthorityProvider,
     Error, TransportConfig, MIN_ADULT_AGE,
 };
 use bytes::Bytes;
 use ed25519_dalek::{Keypair, PublicKey, Signature, Signer, KEYPAIR_LENGTH};
 use itertools::Itertools;
+use secured_linked_list::SecuredLinkedList;
 use sn_messaging::{
     client::ClientMsg, node::RoutingMsg, DestInfo, DstLocation, EndUser, Itinerary, MessageType,
     WireMsg,
 };
-use std::{collections::BTreeSet, net::SocketAddr, sync::Arc};
+use std::{
+    collections::BTreeSet,
+    fmt::{self, Debug, Formatter},
+    net::SocketAddr,
+    sync::Arc,
+};
+
 use tokio::{sync::mpsc, task};
 use xor_name::{Prefix, XorName};
 
@@ -237,7 +244,7 @@ impl Routing {
     }
 
     /// Returns the Section Proof Chain
-    pub async fn section_chain(&self) -> SectionChain {
+    pub async fn section_chain(&self) -> SecuredLinkedList {
         self.dispatcher.core.lock().await.section_chain().clone()
     }
 
@@ -420,7 +427,7 @@ impl Routing {
     }
 
     /// Returns our section proof chain.
-    pub async fn our_history(&self) -> SectionChain {
+    pub async fn our_history(&self) -> SecuredLinkedList {
         self.dispatcher.core.lock().await.section().chain().clone()
     }
 
@@ -437,6 +444,12 @@ impl Drop for Routing {
     }
 }
 
+impl Debug for Routing {
+    fn fmt(&self, f: &mut Formatter) -> fmt::Result {
+        write!(f, "Routing")
+    }
+}
+
 // Listen for incoming connection events and handle them.
 async fn handle_connection_events(
     dispatcher: Arc<Dispatcher>,
